@@ -24,7 +24,9 @@ __all__ = (
     "ListSecretsPaginatorName",
     "SortOrderTypeType",
     "StatusTypeType",
+    "SecretsManagerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -35,6 +37,7 @@ FilterNameStringTypeType = Literal[
 ListSecretsPaginatorName = Literal["list_secrets"]
 SortOrderTypeType = Literal["asc", "desc"]
 StatusTypeType = Literal["Failed", "InProgress", "InSync"]
+SecretsManagerServiceName = Literal["secretsmanager"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -188,6 +191,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -336,4 +340,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_secrets"]
