@@ -540,6 +540,7 @@ _OptionalRotateSecretRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "RotationLambdaARN": str,
         "RotationRules": "RotationRulesTypeTypeDef",
+        "RotateImmediately": bool,
     },
     total=False,
 )
@@ -565,6 +566,8 @@ RotationRulesTypeTypeDef = TypedDict(
     "RotationRulesTypeTypeDef",
     {
         "AutomaticallyAfterDays": int,
+        "Duration": str,
+        "ScheduleExpression": str,
     },
     total=False,
 )
